from em_tasks.utils.pipelines.base import BasePipeline
from em_tasks import logger


class EbayProductsFilterPipeline(BasePipeline):
  def __init__(self, max_shipping_days=14, min_seller_rating=95):
    self.max_shipping_days = max_shipping_days
    self.min_seller_rating = min_seller_rating

  def execute(self, product):
    has_only_default_variant = product.get('has_only_default_variant', True)
    if not has_only_default_variant:
      return

    shipping_days_max = product.get('shipping_days_max', None)
    if shipping_days_max and shipping_days_max > self.max_shipping_days:
      logger.debug('[ShippingTimeInvalid] %s', product['product_id'])
      return

    seller_rating = product.get('seller_rating', 0)
    if seller_rating and seller_rating < self.min_seller_rating:
      logger.debug(
        '[SellerRatingInvalid] ProductId: %s, SellerRating: %s',
        product['product_id'], seller_rating)
      return

    return product
