import json
import pdb

from shopping_utils.google_shopping import GoogleShopping

from em_tasks import logger
from em_tasks.utils.spree.base_repricer import SpreeBaseRepricer
from em_tasks.spree.product_util import ProductUtil
from em_tasks.store.store_util import StoreUtil
from em_tasks.store.models import *


class SpreeAmzRepricer(SpreeBaseRepricer):
  def __init__(self, store_code, marketplace, offer_service, price_caculator):
    super(SpreeAmzRepricer, self).__init__()

    self.condition = 'new'

    self.store = StoreUtil.get_store_by_code(store_code)
    if not self.store:
      return

    credential = json.loads(self.store.api_credential)
    self.product_util = ProductUtil(credential['endpoint'], credential['api_key'], credential.get('api_version', 'v1'))
    # self.product_util = ProductUtil('http://localhost:3000', credential['api_key'], credential.get('api_version', 'v1'))

    self.marketplace = marketplace
    self.offer_service = offer_service
    self.price_calc = price_caculator

    self.gss = dict()
    # gmc_stores = GmcStore.select().execute()
    # for gmc_store in gmc_stores:
    #   self.gss[gmc_store.id] = GoogleShopping(
    #     gmc_store.merchant_id, json.loads(gmc_store.service_account_data))

  def run(self):
    batch_size = 250
    prods = dict()
    for amz_prod in self.product_util.get_amz_products(self.marketplace):
      prods[amz_prod['product_id']] = amz_prod
      if len(prods) < batch_size:
        continue

      self.process_products(prods)
      prods.clear()

    if prods:
      self.process_products(prods)
      prods.clear()

  def process_products(self, prods):
    offers = dict()
    asins = [prod['source_product_id'] for prod in prods.values()]
    src_offers = self.offer_service.get_offers(self.marketplace, asins, self.condition)
    if not src_offers:
      return

    for asin, src_offer in src_offers.items():
      offers[asin] = {'asin': asin, 'src_offer': src_offer}
      offer = self.price_calc.calc_offer(src_offer)
      if offer:
        offers[asin].update(offer)
      else:
        offers[asin] = offer

    for _, prod in prods.items():
      asin = prod['source_product_id']
      if asin in offers:
        offer = offers[asin]
        prod['offer'] = offer

    # logger.debug('[Products] %s', prods)
    store_offers = self.product_util.set_products_offer(prods)
    # try:
    #   self.update_gmc_offers(store_offers)
    # except Exception as e:
    #   logger.exception(e)
